Pizza.py Users Manual
Author: http://pizza.sandia.gov - Sandia National Laboratories

Pizza.py WWW Site - Pizza.py Documentation - Pizza.py Tools

#

### Pizza.py Documentation

#### Version info:

The Pizza.py "version" is the date when it was released, such as 1 May 2010. Pizza.py is updated continuously. Whenever we fix a bug or add a feature, we release it immediately, and post a notice on this page of the WWW site. Each dated copy of Pizza.py contains all the features and bug-fixes up to and including that version date. The version date is printed to the screen and logfile every time you run Pizza.py. It is also in the file src/version.h and in the Pizza.py directory name created when you unpack a tarball.

- If you browse the HTML or PDF doc pages on the Pizza.py WWW site, they always describe the most current version of Pizza.py.
- If you browse the HTML or PDF doc pages included in your tarball, they describe the version you have.

Pizza.py is a loosely integrated collection of tools written in Python, many of which provide pre- and post-processing capability for the LAMMPS molecular dynamics and ChemCell cell simulator packages. There are tools to create input files, convert between file formats, process log and dump files, create plots, and visualize and animate simulation snapshots.

The name Pizza.py is meant to evoke the aroma of a collection of "toppings" that the user can combine in different ways on a "crust" of basic functionality, with Python as the "cheese" that glues everything together.

The maintainer of Pizza.py is Steve Plimpton at Sandia National Laboratories, a US Department of Energy (DOE) laboratory. Many of the tools were written by Matt Jones, a BYU student who spent a summer at Sandia. The Pizza.py WWW Site at http://pizza.sandia.gov has more information about Pizza.py and its uses.

The Pizza.py documentation is organized into the following sections. If you find errors or omissions in this manual or have suggestions for useful information to add, please send an email to sjplimp@sandia.gov so we can improve the Pizza.py documentation.

PDF file of the entire manual, generated by htmldoc

1. Introduction
   1.1 What is Pizza.py
   1.2 Open source distribution
   1.3 Acknowledgements
2. Installing Pizza.py
   2.1 Installing Python
   2.2 Running Pizza.py
   2.3 Setting up the DEFAULTS.py file
   2.4 Installing additional Python packages
   2.5 Installing other software
3. Basics of using Pizza.py
   3.1 Python syntax
   3.2 Pizza.py command line arguments
   3.3 Pizza.py extensions to the Python interpreter
   3.4 Using Pizza.py tools
   3.5 Runnning Pizza.py and Python scripts
   3.6 Error messages
4. Tools within Pizza.py
5. Example scripts
6. Extending Pizza.py

List of tools in Pizza.py:

animate.py | Animate a series of image files
bdump.py | Read LAMMPS dump local files with bond info
cdata.py | Read, write, manipulate ChemCell data files
chain.py | Create bead-spring chains for LAMMPS input
cfg.py | Convert LAMMPS snapshots to CFG format
clog.py | Read ChemCell log files and extract species data
data.py | Read, write, manipulate LAMMPS data files
dump.py | Read, write, manipulate dump files and particle attributes
ensight.py | Convert LAMMPS snapshots to Ensight format
gl.py | 3d interactive visualization via OpenGL
gnu.py | Create plots via GnuPlot plotting program
histo.py | Particle density histogram from a dump
image.py | View and manipulate images
ldump.py | Read LAMMPS dump files with line info
log.py | Read LAMMPS log files and extract thermodynamic data
matlab.py | Create plots via MatLab numerical analysis program
mdump.py | Read, write, manipulate mesh dump files
pair.py | Compute LAMMPS pairwise energies
patch.py | Create patchy Lennard-Jones particles for LAMMPS input
pdbfile.py | Read, write PDB files in combo with LAMMPS snapshots
plotview.py | Plot multiple vectors from a data set
rasmol.py | 3d visualization via RasMol program
raster.py | 3d visualization via Raster3d program
svg.py | 3d visualization via SVG files
tdump.py | Read LAMMPS dump files with triangle info
vcr.py | VCR-style GUI for 3d interactive OpenGL visualization
vec.py | Create numeric vectors from columns in file or list of vecs
vtk.py | Convert LAMMPS snapshots to VTK format
vmd.py | Wrapper on VMD visualization package
xyz.py | Convert LAMMPS snapshots to XYZ format